pub async fn garbage_collect_task(
receiver: Receiver<()>,
node: DarkfiNodePtr,
) -> Result<()>Expand description
Async task used for purging unreferenced trees and erroneous pending transactions from the nodes mempool.
pub async fn garbage_collect_task(
receiver: Receiver<()>,
node: DarkfiNodePtr,
) -> Result<()>Async task used for purging unreferenced trees and erroneous pending transactions from the nodes mempool.