macro_rules! trigger_queue_check {
($receiver:ident, $label:tt) => { ... };
}Expand description
Auxiliary macro to check if channel receiver is empty so we can abort current iteration.
macro_rules! trigger_queue_check {
($receiver:ident, $label:tt) => { ... };
}Auxiliary macro to check if channel receiver is empty so we can abort current iteration.